@@ -145,22 +145,37 @@ def test_hubbing_edge():
             ],
         }
     }
+    dic3 = {
+        "Article": {
+            "title": "Transhumanism in Computergames",
+            "Authors": [
+                {
+                    "firstName": "William",
+                    "lastName": "Gibson",
+                    "affiliation": [{"name": "University 1"}],
+                },
+            ],
+        }
+    }
     d2g = Dict2graph()
     d2g.add_node_transformation(
         [
             Transformer.match_nodes().do(NodeTrans.PopListHubNodes()),
             Transformer.match_nodes().do(NodeTrans.RemoveListItemLabels()),
-            Transformer.match_nodes("Article").do(
-                NodeTrans.CreateHubbing(
-                    follow_nodes_labels=["Authors", "affiliation"],
-                    merge_mode="edge",
-                    hub_labels=["Contribution"],
-                )
-            ),
         ]
     )
+    hub_trans = Transformer.match_nodes("Article").do(
+        NodeTrans.CreateHubbing(
+            follow_nodes_labels=["Authors", "affiliation"],
+            merge_mode="edge",
+            hub_labels=["Contribution"],
+            hub_incomplete_chains=True,
+        )
+    )
+    d2g.add_node_transformation(hub_trans)
     d2g.parse(dic1)
     d2g.parse(dic2)
+    d2g.parse(dic3)
     d2g.merge(DRIVER)
     result = get_all_neo4j_nodes_with_rels(DRIVER)
     # print(json.dumps(result, indent=2))
@@ -181,6 +196,11 @@ def test_hubbing_edge():
             "props": {"firstName": "Mike", "lastName": "Pondsmith"},
             "outgoing_rels": [],
         },
+        {
+            "labels": ["Authors"],
+            "props": {"firstName": "William", "lastName": "Gibson"},
+            "outgoing_rels": [],
+        },
         {
             "labels": ["Article"],
             "props": {"title": "Science Behind The Cyberpunk-Genres Awesomeness"},
@@ -199,6 +219,14 @@ def test_hubbing_edge():
             "labels": ["Article"],
             "props": {"title": "Transhumanism in Computergames"},
             "outgoing_rels": [
+                {
+                    "rel_props": {},
+                    "rel_type": "Article_HAS_Contribution",
+                    "rel_target_node": {
+                        "labels": ["Contribution"],
+                        "props": {"id": "8487f076ec304ed104156566b47d250b"},
+                    },
+                },
                 {
                     "rel_props": {},
                     "rel_type": "Article_HAS_Contribution",
@@ -206,7 +234,7 @@ def test_hubbing_edge():
                         "labels": ["Contribution"],
                         "props": {"id": "d6d0f91b22b1aa33ccb4584344c07508"},
                     },
-                }
+                },
             ],
         },
         {
@@ -231,6 +259,36 @@ def test_hubbing_edge():
                 },
             ],
         },
+        {
+            "labels": ["Contribution"],
+            "props": {"id": "8487f076ec304ed104156566b47d250b"},
+            "outgoing_rels": [
+                {
+                    "rel_props": {"_list_item_index": 0},
+                    "rel_type": "Contribution_HAS_Authors",
+                    "rel_target_node": {
+                        "labels": ["Authors"],
+                        "props": {"firstName": "William", "lastName": "Gibson"},
+                    },
+                },
+                {
+                    "rel_props": {"_list_item_index": 0},
+                    "rel_type": "Contribution_HAS_Authors",
+                    "rel_target_node": {
+                        "labels": ["Authors"],
+                        "props": {"firstName": "Mike", "lastName": "Pondsmith"},
+                    },
+                },
+                {
+                    "rel_props": {"_list_item_index": 0},
+                    "rel_type": "Contribution_HAS_affiliation",
+                    "rel_target_node": {
+                        "labels": ["affiliation"],
+                        "props": {"name": "University 1"},
+                    },
+                },
+            ],
+        },
         {
             "labels": ["Contribution"],
             "props": {"id": "d6d0f91b22b1aa33ccb4584344c07508"},
@@ -243,14 +301,6 @@ def test_hubbing_edge():
                         "props": {"firstName": "Mike", "lastName": "Pondsmith"},
                     },
                 },
-                {
-                    "rel_props": {"_list_item_index": 0},
-                    "rel_type": "Contribution_HAS_affiliation",
-                    "rel_target_node": {
-                        "labels": ["affiliation"],
-                        "props": {"name": "University 1"},
-                    },
-                },
                 {
                     "rel_props": {"_list_item_index": 1},
                     "rel_type": "Contribution_HAS_affiliation",
@@ -513,8 +563,262 @@ def wip_test_pubmed_article():
     assert_result(result, expected_result_nodes)
 
 
+def test_pubmed_author_hubbing():
+    wipe_all_neo4j_data(DRIVER)
+    data = {
+        "PubMedArticle": {
+            "PMID": "12345",
+            "AuthorList": {
+                "CompleteYN": "Y",
+                "Author": [
+                    {
+                        "LastName": "Clay",
+                        "ForeName": "J",
+                    },
+                    {
+                        "LastName": "Rutha",
+                        "ForeName": "Heatherford",
+                    },
+                    {
+                        "LastName": "Kalla",
+                        "ForeName": "Roger",
+                        "AffiliationInfo": [
+                            {
+                                "Affiliation": "University Hospital Bern",
+                                "otherstuff": {
+                                    "building_count": 23,
+                                    "altname": "HospBern",
+                                },
+                            },
+                            {
+                                "Affiliation": "German Center for Vertigo and Balance Disorders"
+                            },
+                        ],
+                    },
+                    {
+                        "LastName": "Strupp",
+                        "ForeName": "Michael",
+                        "AffiliationInfo": [
+                            {
+                                "Affiliation": "German Center for Vertigo and Balance Disorders"
+                            }
+                        ],
+                    },
+                    {
+                        "LastName": "Miller",
+                        "ForeName": "Tom",
+                        "AffiliationInfo": [
+                            {"Affiliation": "University Hospital Bern"}
+                        ],
+                    },
+                ],
+            },
+        }
+    }
+    d2g = Dict2graph()
+
+    d2g.add_transformation(
+        [
+            Transformer.match_nodes().do(
+                [
+                    NodeTrans.PopListHubNodes(),
+                    NodeTrans.RemoveListItemLabels(),
+                ]
+            ),
+            Transformer.match_nodes("AffiliationInfo").do(
+                NodeTrans.OverrideLabel("Affiliation"),
+            ),
+            Transformer.match_nodes("PubMedArticle").do(
+                NodeTrans.MergeChildNodes(
+                    child_labels="AuthorList",
+                    prefix_merged_props_with_primary_label_of_child=False,
+                )
+            ),
+            Transformer.match_nodes("PubMedArticle").do(
+                NodeTrans.CreateHubbing(
+                    follow_nodes_labels=["Author", "Affiliation"],
+                    merge_mode="edge",
+                    hub_labels=["Contribution"],
+                )
+            ),
+        ]
+    )
+
+    d2g.parse(data)
+    d2g.merge(DRIVER)
+    result = get_all_neo4j_nodes_with_rels(DRIVER)
+    expected_result_nodes: dict = [
+        {
+            "labels": ["Author"],
+            "props": {"ForeName": "J", "LastName": "Clay"},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["Author"],
+            "props": {"ForeName": "Heatherford", "LastName": "Rutha"},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["Author"],
+            "props": {"ForeName": "Roger", "LastName": "Kalla"},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["Author"],
+            "props": {"ForeName": "Michael", "LastName": "Strupp"},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["Author"],
+            "props": {"ForeName": "Tom", "LastName": "Miller"},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["otherstuff"],
+            "props": {"altname": "HospBern", "building_count": 23},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["Affiliation"],
+            "props": {"Affiliation": "University Hospital Bern"},
+            "outgoing_rels": [
+                {
+                    "rel_props": {},
+                    "rel_type": "Affiliation_HAS_otherstuff",
+                    "rel_target_node": {
+                        "labels": ["otherstuff"],
+                        "props": {"altname": "HospBern", "building_count": 23},
+                    },
+                }
+            ],
+        },
+        {
+            "labels": ["Affiliation"],
+            "props": {"Affiliation": "German Center for Vertigo and Balance Disorders"},
+            "outgoing_rels": [],
+        },
+        {
+            "labels": ["PubMedArticle"],
+            "props": {"CompleteYN": "Y", "PMID": "12345"},
+            "outgoing_rels": [
+                {
+                    "rel_props": {},
+                    "rel_type": "PubMedArticle_HAS_Contribution",
+                    "rel_target_node": {
+                        "labels": ["Contribution"],
+                        "props": {"id": "8f492ab45657303e8a9bd4334d41c428"},
+                    },
+                },
+                {
+                    "rel_props": {},
+                    "rel_type": "PubMedArticle_HAS_Contribution",
+                    "rel_target_node": {
+                        "labels": ["Contribution"],
+                        "props": {"id": "97c45bbc829267c994a9e56e25b01a97"},
+                    },
+                },
+                {
+                    "rel_props": {},
+                    "rel_type": "PubMedArticle_HAS_Contribution",
+                    "rel_target_node": {
+                        "labels": ["Contribution"],
+                        "props": {"id": "97ad3f47b0e310c023933e4db4dc502c"},
+                    },
+                },
+            ],
+        },
+        {
+            "labels": ["Contribution"],
+            "props": {"id": "8f492ab45657303e8a9bd4334d41c428"},
+            "outgoing_rels": [
+                {
+                    "rel_props": {"_list_item_index": 1},
+                    "rel_type": "Contribution_HAS_Author",
+                    "rel_target_node": {
+                        "labels": ["Author"],
+                        "props": {"ForeName": "Heatherford", "LastName": "Rutha"},
+                    },
+                },
+                {
+                    "rel_props": {"_list_item_index": 0},
+                    "rel_type": "Contribution_HAS_Author",
+                    "rel_target_node": {
+                        "labels": ["Author"],
+                        "props": {"ForeName": "J", "LastName": "Clay"},
+                    },
+                },
+            ],
+        },
+        {
+            "labels": ["Contribution"],
+            "props": {"id": "97ad3f47b0e310c023933e4db4dc502c"},
+            "outgoing_rels": [
+                {
+                    "rel_props": {"_list_item_index": 4},
+                    "rel_type": "Contribution_HAS_Author",
+                    "rel_target_node": {
+                        "labels": ["Author"],
+                        "props": {"ForeName": "Tom", "LastName": "Miller"},
+                    },
+                },
+                {
+                    "rel_props": {"_list_item_index": 2},
+                    "rel_type": "Contribution_HAS_Author",
+                    "rel_target_node": {
+                        "labels": ["Author"],
+                        "props": {"ForeName": "Roger", "LastName": "Kalla"},
+                    },
+                },
+                {
+                    "rel_props": {"_list_item_index": 0},
+                    "rel_type": "Contribution_HAS_Affiliation",
+                    "rel_target_node": {
+                        "labels": ["Affiliation"],
+                        "props": {"Affiliation": "University Hospital Bern"},
+                    },
+                },
+            ],
+        },
+        {
+            "labels": ["Contribution"],
+            "props": {"id": "97c45bbc829267c994a9e56e25b01a97"},
+            "outgoing_rels": [
+                {
+                    "rel_props": {"_list_item_index": 3},
+                    "rel_type": "Contribution_HAS_Author",
+                    "rel_target_node": {
+                        "labels": ["Author"],
+                        "props": {"ForeName": "Michael", "LastName": "Strupp"},
+                    },
+                },
+                {
+                    "rel_props": {"_list_item_index": 2},
+                    "rel_type": "Contribution_HAS_Author",
+                    "rel_target_node": {
+                        "labels": ["Author"],
+                        "props": {"ForeName": "Roger", "LastName": "Kalla"},
+                    },
+                },
+                {
+                    "rel_props": {"_list_item_index": 0},
+                    "rel_type": "Contribution_HAS_Affiliation",
+                    "rel_target_node": {
+                        "labels": ["Affiliation"],
+                        "props": {
+                            "Affiliation": "German Center for Vertigo and Balance Disorders"
+                        },
+                    },
+                },
+            ],
+        },
+    ]
+    # print("DIFF:", DeepDiff(expected_result_nodes, result, ignore_order=True))
+    assert_result(result, expected_result_nodes)
+
+
 if __name__ == "__main__" or os.getenv("DICT2GRAPH_RUN_ALL_TESTS", None) == "true":
-    # test_merge_two_dicts_and_remove_list_hubs()
+    test_merge_two_dicts_and_remove_list_hubs()
     test_hubbing_edge()
     test_pubmed_article_base_test()
     # wip_test_pubmed_article()
+    test_pubmed_author_hubbing()
